#[repr(u8)]pub enum Selcc {
CHANNEL_0_RISING = 0,
CHANNEL_0_FALLING = 1,
CHANNEL_1_RISING = 2,
CHANNEL_1_FALLING = 3,
CHANNEL_2_RISING = 4,
CHANNEL_2_FALLING = 5,
_RESERVED_6 = 6,
_RESERVED_7 = 7,
}Variants
CHANNEL_0_RISING = 0
Channel 0 Rising Edge. Rising edge of the signal on capture channel 0 clears the timer (if bit 4 is set).
CHANNEL_0_FALLING = 1
Channel 0 Falling Edge. Falling edge of the signal on capture channel 0 clears the timer (if bit 4 is set).
CHANNEL_1_RISING = 2
Channel 1 Rising Edge. Rising edge of the signal on capture channel 1 clears the timer (if bit 4 is set).
CHANNEL_1_FALLING = 3
Channel 1 Falling Edge. Falling edge of the signal on capture channel 1 clears the timer (if bit 4 is set).
CHANNEL_2_RISING = 4
Channel 2 Rising Edge. Rising edge of the signal on capture channel 2 clears the timer (if bit 4 is set).
CHANNEL_2_FALLING = 5
Channel 2 Falling Edge. Falling edge of the signal on capture channel 2 clears the timer (if bit 4 is set).
_RESERVED_6 = 6
_RESERVED_7 = 7
Implementations